Non-parametric tests for Multiple Comparison — STAC 0.7 documentation

### Navigation

- index
- STAC 0.7 documentation »

# Non-parametric tests for Multiple Comparison

`wilcoxon`(x[, y, zero_method, correction]) | Calculate the Wilcoxon signed-rank test.
`mannwhitneyu`(x, y[, use_continuity]) | Computes the Mann-Whitney rank test on samples x and y.

`binomial_sign_test`(*args) | Performs a binomial sign test for two dependent samples.

### Navigation

- index
- STAC 0.7 documentation »